@@ -8,14 +8,8 @@ from typing import Any, TypeVar, cast
 
 from bleak.backends.device import BLEDevice
 from bleak.backends.scanner import AdvertisementData
-from bleak.backends.service import BleakGATTServiceCollection
 from bleak.exc import BleakDBusError
-from bleak_retry_connector import (
-    BleakError,
-    BleakNotFoundError,
-    ble_device_has_changed,
-    get_device,
-)
+from bleak_retry_connector import BLEAK_RETRY_EXCEPTIONS, BleakNotFoundError, get_device
 
 from .const import (
     APPLE_MFR_ID,
@@ -60,12 +54,7 @@ UPDATE_IN_PROGRESS_DEFER_SECONDS = 29.50
 
 RETRY_BACKOFF_EXCEPTIONS = (BleakDBusError, DisconnectedError)
 
-RETRY_EXCEPTIONS = (
-    asyncio.TimeoutError,
-    ResponseError,
-    BleakError,
-    EOFError,
-)
+RETRY_EXCEPTIONS = (ResponseError, *BLEAK_RETRY_EXCEPTIONS)
 
 # 255 seems to be broadcast randomly when
 # there is no update from the lock.
@@ -214,7 +203,6 @@ class PushLock:
         self._cancel_deferred_update: asyncio.TimerHandle | None = None
         self.last_error: str | None = None
         self.auth_error = False
-        self._cached_services: BleakGATTServiceCollection | None = None
 
     @property
     def local_name(self) -> str | None:
@@ -287,20 +275,9 @@ class PushLock:
 
     def set_ble_device(self, ble_device: BLEDevice) -> None:
         """Set the ble device."""
-        if self._ble_device and ble_device_has_changed(self._ble_device, ble_device):
-            _LOGGER.debug(
-                "%s: New ble device details, clearing cached services", self.name
-            )
-            self._cached_services = None
         self._ble_device = ble_device
         self._address = ble_device.address
 
-    def _memorize_services(self, lock: Lock) -> None:
-        """Memorize the services."""
-        if not self._cached_services:
-            assert lock.client is not None  # nosec
-            self._cached_services = lock.client.services
-
     def _get_lock_instance(self) -> Lock:
         """Get the lock instance."""
         assert self._ble_device is not None  # nosec
@@ -312,7 +289,6 @@ class PushLock:
             self._lock_key_index,
             self.name,
             self._lock_info,
-            cached_services=self._cached_services,
         )
 
     async def _cancel_any_update(self) -> None:
@@ -346,7 +322,6 @@ class PushLock:
         try:
             async with lock:
                 await lock.force_lock()
-                self._memorize_services(lock)
         except Exception:
             self._callback_state(LockState(LockStatus.UNKNOWN, self.door_status))
             raise
@@ -367,7 +342,6 @@ class PushLock:
         try:
             async with lock:
                 await lock.force_unlock()
-                self._memorize_services(lock)
         except Exception:
             self._callback_state(LockState(LockStatus.UNKNOWN, self.door_status))
             raise
@@ -397,7 +371,6 @@ class PushLock:
                 if not self._lock_info:
                     self._lock_info = await lock.lock_info()
                 state = await lock.status()
-                self._memorize_services(lock)
         except asyncio.CancelledError:
             _LOGGER.debug(
                 "%s: In-progress update canceled due "
